==> robosystems_client-0.1.14.tar.gz: robosystems_client-0.1.14/robosystems_client/api/subgraphs/create_subgraph.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.create_subgraph_request import CreateSubgraphRequest
from ...models.http_validation_error import HTTPValidationError
from ...models.subgraph_response import SubgraphResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
  graph_id: str,
  *,
  body: CreateSubgraphRequest,
  authorization: Union[None, Unset, str] = UNSET,
  auth_token: Union[None, Unset, str] = UNSET,
) -> dict[str, Any]:
  headers: dict[str, Any] = {}
  if not isinstance(authorization, Unset):
    headers["authorization"] = authorization

  cookies = {}
  if auth_token is not UNSET:
    cookies["auth-token"] = auth_token

  _kwargs: dict[str, Any] = {
    "method": "post",
    "url": f"/v1/{graph_id}/subgraphs",
    "cookies": cookies,
  }

  _kwargs["json"] = body.to_dict()

  headers["Content-Type"] = "application/json"

  _kwargs["headers"] = headers
  return _kwargs


def _parse_response(
  *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, SubgraphResponse]]:
  if response.status_code == 201:
    response_201 = SubgraphResponse.from_dict(response.json())

    return response_201
  if response.status_code == 422:
    response_422 = HTTPValidationError.from_dict(response.json())

    return response_422
  if client.raise_on_unexpected_status:
    raise errors.UnexpectedStatus(response.status_code, response.content)
  else:
    return None


def _build_response(
  *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, SubgraphResponse]]:
  return Response(
    status_code=HTTPStatus(response.status_code),
    content=response.content,
    headers=response.headers,
    parsed=_parse_response(client=client, response=response),
  )


def sync_detailed(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  body: CreateSubgraphRequest,
  authorization: Union[None, Unset, str] = UNSET,
  auth_token: Union[None, Unset, str] = UNSET,
) -> Response[Union[HTTPValidationError, SubgraphResponse]]:
  """Create Subgraph

   Create a new subgraph within a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have 'admin' permission on the parent graph
  - Parent graph tier must support subgraphs (Enterprise or Premium only)
  - Must be within subgraph quota limits
  - Subgraph name must be unique within the parent graph

  **Returns:**
  - Created subgraph details including its unique ID

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      authorization (Union[None, Unset, str]):
      auth_token (Union[None, Unset, str]):
      body (CreateSubgraphRequest): Request model for creating a subgraph.

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Response[Union[HTTPValidationError, SubgraphResponse]]
  """

  kwargs = _get_kwargs(
    graph_id=graph_id,
    body=body,
    authorization=authorization,
    auth_token=auth_token,
  )

  response = client.get_httpx_client().request(
    **kwargs,
  )

  return _build_response(client=client, response=response)


def sync(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  body: CreateSubgraphRequest,
  authorization: Union[None, Unset, str] = UNSET,
  auth_token: Union[None, Unset, str] = UNSET,
) -> Optional[Union[HTTPValidationError, SubgraphResponse]]:
  """Create Subgraph

   Create a new subgraph within a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have 'admin' permission on the parent graph
  - Parent graph tier must support subgraphs (Enterprise or Premium only)
  - Must be within subgraph quota limits
  - Subgraph name must be unique within the parent graph

  **Returns:**
  - Created subgraph details including its unique ID

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      authorization (Union[None, Unset, str]):
      auth_token (Union[None, Unset, str]):
      body (CreateSubgraphRequest): Request model for creating a subgraph.

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Union[HTTPValidationError, SubgraphResponse]
  """

  return sync_detailed(
    graph_id=graph_id,
    client=client,
    body=body,
    authorization=authorization,
    auth_token=auth_token,
  ).parsed


async def asyncio_detailed(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  body: CreateSubgraphRequest,
  authorization: Union[None, Unset, str] = UNSET,
  auth_token: Union[None, Unset, str] = UNSET,
) -> Response[Union[HTTPValidationError, SubgraphResponse]]:
  """Create Subgraph

   Create a new subgraph within a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have 'admin' permission on the parent graph
  - Parent graph tier must support subgraphs (Enterprise or Premium only)
  - Must be within subgraph quota limits
  - Subgraph name must be unique within the parent graph

  **Returns:**
  - Created subgraph details including its unique ID

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      authorization (Union[None, Unset, str]):
      auth_token (Union[None, Unset, str]):
      body (CreateSubgraphRequest): Request model for creating a subgraph.

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Response[Union[HTTPValidationError, SubgraphResponse]]
  """

  kwargs = _get_kwargs(
    graph_id=graph_id,
    body=body,
    authorization=authorization,
    auth_token=auth_token,
  )

  response = await client.get_async_httpx_client().request(**kwargs)

  return _build_response(client=client, response=response)


async def asyncio(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  body: CreateSubgraphRequest,
  authorization: Union[None, Unset, str] = UNSET,
  auth_token: Union[None, Unset, str] = UNSET,
) -> Optional[Union[HTTPValidationError, SubgraphResponse]]:
  """Create Subgraph

   Create a new subgraph within a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have 'admin' permission on the parent graph
  - Parent graph tier must support subgraphs (Enterprise or Premium only)
  - Must be within subgraph quota limits
  - Subgraph name must be unique within the parent graph

  **Returns:**
  - Created subgraph details including its unique ID

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      authorization (Union[None, Unset, str]):
      auth_token (Union[None, Unset, str]):
      body (CreateSubgraphRequest): Request model for creating a subgraph.

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Union[HTTPValidationError, SubgraphResponse]
  """

  return (
    await asyncio_detailed(
      graph_id=graph_id,
      client=client,
      body=body,
      authorization=authorization,
      auth_token=auth_token,
    )
  ).parsed

==> robosystems_client-0.1.19.tar.gz: robosystems_client-0.1.19/robosystems_client/api/subgraphs/create_subgraph.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.create_subgraph_request import CreateSubgraphRequest
from ...models.http_validation_error import HTTPValidationError
from ...models.subgraph_response import SubgraphResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
  graph_id: str,
  *,
  body: CreateSubgraphRequest,
  token: Union[None, Unset, str] = UNSET,
  authorization: Union[None, Unset, str] = UNSET,
) -> dict[str, Any]:
  headers: dict[str, Any] = {}
  if not isinstance(authorization, Unset):
    headers["authorization"] = authorization

  params: dict[str, Any] = {}

  json_token: Union[None, Unset, str]
  if isinstance(token, Unset):
    json_token = UNSET
  else:
    json_token = token
  params["token"] = json_token

  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

  _kwargs: dict[str, Any] = {
    "method": "post",
    "url": f"/v1/graphs/{graph_id}/subgraphs",
    "params": params,
  }

  _kwargs["json"] = body.to_dict()

  headers["Content-Type"] = "application/json"

  _kwargs["headers"] = headers
  return _kwargs


def _parse_response(
  *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, SubgraphResponse]]:
  if response.status_code == 201:
    response_201 = SubgraphResponse.from_dict(response.json())

    return response_201
  if response.status_code == 422:
    response_422 = HTTPValidationError.from_dict(response.json())

    return response_422
  if client.raise_on_unexpected_status:
    raise errors.UnexpectedStatus(response.status_code, response.content)
  else:
    return None


def _build_response(
  *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, SubgraphResponse]]:
  return Response(
    status_code=HTTPStatus(response.status_code),
    content=response.content,
    headers=response.headers,
    parsed=_parse_response(client=client, response=response),
  )


def sync_detailed(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  body: CreateSubgraphRequest,
  token: Union[None, Unset, str] = UNSET,
  authorization: Union[None, Unset, str] = UNSET,
) -> Response[Union[HTTPValidationError, SubgraphResponse]]:
  """Create Subgraph

   Create a new subgraph within a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have 'admin' permission on the parent graph
  - Parent graph tier must support subgraphs (Enterprise or Premium only)
  - Must be within subgraph quota limits
  - Subgraph name must be unique within the parent graph

  **Returns:**
  - Created subgraph details including its unique ID

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      token (Union[None, Unset, str]): JWT token for SSE authentication
      authorization (Union[None, Unset, str]):
      body (CreateSubgraphRequest): Request model for creating a subgraph.

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Response[Union[HTTPValidationError, SubgraphResponse]]
  """

  kwargs = _get_kwargs(
    graph_id=graph_id,
    body=body,
    token=token,
    authorization=authorization,
  )

  response = client.get_httpx_client().request(
    **kwargs,
  )

  return _build_response(client=client, response=response)


def sync(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  body: CreateSubgraphRequest,
  token: Union[None, Unset, str] = UNSET,
  authorization: Union[None, Unset, str] = UNSET,
) -> Optional[Union[HTTPValidationError, SubgraphResponse]]:
  """Create Subgraph

   Create a new subgraph within a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have 'admin' permission on the parent graph
  - Parent graph tier must support subgraphs (Enterprise or Premium only)
  - Must be within subgraph quota limits
  - Subgraph name must be unique within the parent graph

  **Returns:**
  - Created subgraph details including its unique ID

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      token (Union[None, Unset, str]): JWT token for SSE authentication
      authorization (Union[None, Unset, str]):
      body (CreateSubgraphRequest): Request model for creating a subgraph.

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Union[HTTPValidationError, SubgraphResponse]
  """

  return sync_detailed(
    graph_id=graph_id,
    client=client,
    body=body,
    token=token,
    authorization=authorization,
  ).parsed


async def asyncio_detailed(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  body: CreateSubgraphRequest,
  token: Union[None, Unset, str] = UNSET,
  authorization: Union[None, Unset, str] = UNSET,
) -> Response[Union[HTTPValidationError, SubgraphResponse]]:
  """Create Subgraph

   Create a new subgraph within a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have 'admin' permission on the parent graph
  - Parent graph tier must support subgraphs (Enterprise or Premium only)
  - Must be within subgraph quota limits
  - Subgraph name must be unique within the parent graph

  **Returns:**
  - Created subgraph details including its unique ID

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      token (Union[None, Unset, str]): JWT token for SSE authentication
      authorization (Union[None, Unset, str]):
      body (CreateSubgraphRequest): Request model for creating a subgraph.

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Response[Union[HTTPValidationError, SubgraphResponse]]
  """

  kwargs = _get_kwargs(
    graph_id=graph_id,
    body=body,
    token=token,
    authorization=authorization,
  )

  response = await client.get_async_httpx_client().request(**kwargs)

  return _build_response(client=client, response=response)


async def asyncio(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  body: CreateSubgraphRequest,
  token: Union[None, Unset, str] = UNSET,
  authorization: Union[None, Unset, str] = UNSET,
) -> Optional[Union[HTTPValidationError, SubgraphResponse]]:
  """Create Subgraph

   Create a new subgraph within a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have 'admin' permission on the parent graph
  - Parent graph tier must support subgraphs (Enterprise or Premium only)
  - Must be within subgraph quota limits
  - Subgraph name must be unique within the parent graph

  **Returns:**
  - Created subgraph details including its unique ID

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      token (Union[None, Unset, str]): JWT token for SSE authentication
      authorization (Union[None, Unset, str]):
      body (CreateSubgraphRequest): Request model for creating a subgraph.

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Union[HTTPValidationError, SubgraphResponse]
  """

  return (
    await asyncio_detailed(
      graph_id=graph_id,
      client=client,
      body=body,
      token=token,
      authorization=authorization,
    )
  ).parsed
